@@ -1,9 +1,15 @@
-"Main interface for apigateway service type defs"
-from __future__ import annotations
+"""
+Main interface for apigateway service type definitions.
 
+Usage::
+
+    from mypy_boto3.apigateway.type_defs import ThrottleSettingsTypeDef
+
+    data: ThrottleSettingsTypeDef = {...}
+"""
 from datetime import datetime
 import sys
-from typing import Dict, IO, List
+from typing import Dict, IO, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -13,9 +19,75 @@ if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
-from typing import Union
 
 
+__all__ = (
+    "ThrottleSettingsTypeDef",
+    "AccountTypeDef",
+    "ApiKeyIdsTypeDef",
+    "ApiKeyTypeDef",
+    "ApiKeysTypeDef",
+    "ApiStageTypeDef",
+    "AuthorizerTypeDef",
+    "AuthorizersTypeDef",
+    "BasePathMappingTypeDef",
+    "BasePathMappingsTypeDef",
+    "CanarySettingsTypeDef",
+    "ClientCertificateTypeDef",
+    "ClientCertificatesTypeDef",
+    "DeploymentCanarySettingsTypeDef",
+    "MethodSnapshotTypeDef",
+    "DeploymentTypeDef",
+    "DeploymentsTypeDef",
+    "DocumentationPartIdsTypeDef",
+    "DocumentationPartLocationTypeDef",
+    "DocumentationPartTypeDef",
+    "DocumentationPartsTypeDef",
+    "DocumentationVersionTypeDef",
+    "DocumentationVersionsTypeDef",
+    "EndpointConfigurationTypeDef",
+    "DomainNameTypeDef",
+    "DomainNamesTypeDef",
+    "ExportResponseTypeDef",
+    "GatewayResponseTypeDef",
+    "GatewayResponsesTypeDef",
+    "IntegrationResponseTypeDef",
+    "IntegrationTypeDef",
+    "MethodResponseTypeDef",
+    "MethodTypeDef",
+    "ModelTypeDef",
+    "ModelsTypeDef",
+    "PaginatorConfigTypeDef",
+    "PatchOperationTypeDef",
+    "QuotaSettingsTypeDef",
+    "RequestValidatorTypeDef",
+    "RequestValidatorsTypeDef",
+    "ResourceTypeDef",
+    "ResourcesTypeDef",
+    "RestApiTypeDef",
+    "RestApisTypeDef",
+    "SdkResponseTypeDef",
+    "SdkConfigurationPropertyTypeDef",
+    "SdkTypeTypeDef",
+    "SdkTypesTypeDef",
+    "StageKeyTypeDef",
+    "AccessLogSettingsTypeDef",
+    "MethodSettingTypeDef",
+    "StageTypeDef",
+    "StagesTypeDef",
+    "TagsTypeDef",
+    "TemplateTypeDef",
+    "TestInvokeAuthorizerResponseTypeDef",
+    "TestInvokeMethodResponseTypeDef",
+    "UsagePlanKeyTypeDef",
+    "UsagePlanKeysTypeDef",
+    "UsagePlanTypeDef",
+    "UsagePlansTypeDef",
+    "UsageTypeDef",
+    "VpcLinkTypeDef",
+    "VpcLinksTypeDef",
+)
+
 ThrottleSettingsTypeDef = TypedDict(
     "ThrottleSettingsTypeDef", {"burstLimit": int, "rateLimit": float}, total=False
 )
